summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/queries/kexiquerydesignerguieditor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/queries/kexiquerydesignerguieditor.cpp')
-rw-r--r--kexi/plugins/queries/kexiquerydesignerguieditor.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kexi/plugins/queries/kexiquerydesignerguieditor.cpp b/kexi/plugins/queries/kexiquerydesignerguieditor.cpp
index a6205222a..5be541454 100644
--- a/kexi/plugins/queries/kexiquerydesignerguieditor.cpp
+++ b/kexi/plugins/queries/kexiquerydesignerguieditor.cpp
@@ -349,7 +349,7 @@ KexiRelationWidget *KexiQueryDesignerGuiEditor::relationView() const
KexiQueryPart::TempData *
KexiQueryDesignerGuiEditor::tempData() const
{
- return static_cast<KexiQueryPart::TempData*>(tqparentDialog()->tempData());
+ return static_cast<KexiQueryPart::TempData*>(parentDialog()->tempData());
}
static TQString msgCannotSwitch_EmptyDesign() {
@@ -581,7 +581,7 @@ KexiQueryDesignerGuiEditor::beforeSwitchTo(int mode, bool &dontStore)
// if (!d->dataTable->dataAwareObject()->acceptRowEdit())
// return cancelled;
- if (!dirty() && tqparentDialog()->neverSaved()) {
+ if (!dirty() && parentDialog()->neverSaved()) {
KMessageBox::information(this, msgCannotSwitch_EmptyDesign());
return cancelled;
}
@@ -618,13 +618,13 @@ tristate
KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
{
const bool was_dirty = dirty();
- KexiDB::Connection *conn = tqparentDialog()->mainWin()->project()->dbConnection();
+ KexiDB::Connection *conn = parentDialog()->mainWin()->project()->dbConnection();
if (mode==Kexi::NoViewMode || (mode==Kexi::DataViewMode && !tempData()->query())) {
//this is not a SWITCH but a fresh opening in this view mode
if (!m_dialog->neverSaved()) {
if (!loadLayout()) {
//err msg
- tqparentDialog()->settqStatus(conn,
+ parentDialog()->settqStatus(conn,
i18n("Query definition loading failed."),
i18n("Query design may be corrupted so it could not be opened even in text view.\n"
"You can delete the query and create it again."));
@@ -633,13 +633,13 @@ KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
// Invalid queries case:
// KexiDialogBase::switchToViewMode() first opens DesignViewMode,
// and then KexiQueryPart::loadSchemaData() doesn't allocate QuerySchema object
- // do we're carefully looking at tqparentDialog()->schemaData()
- KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(tqparentDialog()->schemaData());
+ // do we're carefully looking at parentDialog()->schemaData()
+ KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(parentDialog()->schemaData());
if (q) {
KexiDB::ResultInfo result;
showFieldsForQuery( q, result );
if (!result.success) {
- tqparentDialog()->settqStatus(&result, i18n("Query definition loading failed."));
+ parentDialog()->settqStatus(&result, i18n("Query definition loading failed."));
tempData()->proposeOpeningInTextViewModeBecauseOfProblems = true;
return false;
}
@@ -662,7 +662,7 @@ KexiQueryDesignerGuiEditor::afterSwitchFrom(int mode)
KexiDB::ResultInfo result;
showFieldsAndRelationsForQuery( tempData()->query(), result );
if (!result.success) {
- tqparentDialog()->settqStatus(&result, i18n("Query definition loading failed."));
+ parentDialog()->settqStatus(&result, i18n("Query definition loading failed."));
return false;
}
}
@@ -813,7 +813,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
KexiDB::BaseExpr* e = query->whereExpression();
KexiDB::BaseExpr* eItem = 0;
while (e) {
- //eat tqparentheses because the expression can be (....) AND (... AND ... )
+ //eat parentheses because the expression can be (....) AND (... AND ... )
while (e && e->toUnary() && e->token()=='(')
e = e->toUnary()->arg();
@@ -826,7 +826,7 @@ void KexiQueryDesignerGuiEditor::showFieldsOrRelationsForQueryInternal(
e = 0;
}
- //eat tqparentheses
+ //eat parentheses
while (eItem && eItem->toUnary() && eItem->token()=='(')
eItem = eItem->toUnary()->arg();
@@ -1077,13 +1077,13 @@ bool KexiQueryDesignerGuiEditor::loadLayout()
//in a case when query tqlayout was not saved, build tqlayout by hand
// -- dynamic cast because of a need for handling invalid queries
// (as in KexiQueryDesignerGuiEditor::afterSwitchFrom()):
- KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(tqparentDialog()->schemaData());
+ KexiDB::QuerySchema * q = dynamic_cast<KexiDB::QuerySchema *>(parentDialog()->schemaData());
if (q) {
showTablesForQuery( q );
KexiDB::ResultInfo result;
showRelationsForQuery( q, result );
if (!result.success) {
- tqparentDialog()->settqStatus(&result, i18n("Query definition loading failed."));
+ parentDialog()->settqStatus(&result, i18n("Query definition loading failed."));
return false;
}
}